@@ -1,10 +1,17 @@
 package Sah::Schema::natnum;
 
-our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2017-08-19'; # DATE
+our $VERSION = '0.070'; # VERSION
 
 our $schema = ['posint', {
     summary => 'Same as posint',
+    description => <<'_',
+
+Natural numbers are those used for counting and ordering. Some definitions, like
+ISO 80000-2 begin the natural numbers with 0. But in this definition, natural
+numbers start with 1. For integers that start at 0, see `nonnegint`.
+
+_
 }, {}];
 
 1;
@@ -22,7 +29,13 @@ Sah::Schema::natnum - Same as posint
 
 =head1 VERSION
 
-This document describes version 0.06 of Sah::Schema::natnum (from Perl distribution Sah-Schemas-Int), released on 2016-07-22.
+This document describes version 0.070 of Sah::Schema::natnum (from Perl distribution Sah-Schemas-Int), released on 2017-08-19.
+
+=head1 DESCRIPTION
+
+Natural numbers are those used for counting and ordering. Some definitions, like
+ISO 80000-2 begin the natural numbers with 0. But in this definition, natural
+numbers start with 1. For integers that start at 0, see C<nonnegint>.
 
 =head1 HOMEPAGE
 
@@ -46,7 +59,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
