@@ -1,11 +1,17 @@
 package Sah::Schema::posint;
 
-our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2017-08-19'; # DATE
+our $VERSION = '0.070'; # VERSION
 
 our $schema = [int => {
     summary   => 'Positive integer (1, 2, ...)',
     min       => 1,
+    description => <<'_',
+
+Zero is not included in this schema because zero is neither positive nor
+negative. See also `nonnegint` for integers that start from 0.
+
+_
 }, {}];
 
 1;
@@ -23,7 +29,12 @@ Sah::Schema::posint - Positive integer (1, 2, ...)
 
 =head1 VERSION
 
-This document describes version 0.06 of Sah::Schema::posint (from Perl distribution Sah-Schemas-Int), released on 2016-07-22.
+This document describes version 0.070 of Sah::Schema::posint (from Perl distribution Sah-Schemas-Int), released on 2017-08-19.
+
+=head1 DESCRIPTION
+
+Zero is not included in this schema because zero is neither positive nor
+negative. See also C<nonnegint> for integers that start from 0.
 
 =head1 HOMEPAGE
 
@@ -47,7 +58,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
